'===========================================================================
'
'                              SAMPLE PROGRAM
'
' to demonstrate the use of the screen utilities written by Tony Martin for
' the Microsoft QuickBASIC compiler version 4.0.
'
' You MUST have started QuickBASIC with the following command line:
'
'                            QB SAMPLE /L QBSCR
'
' in order for the compiler to recognize the library functions.
'
' Sample program and the screen utilities and libraries are (C)opyright 1988
' by:                            Tony Martin
'                           7623 Matera St. #104
'                          Falls Church, VA 22043
'
'===========================================================================

'=== Note that all the following declarations are for the utilities in the
'=== screen utilities package.  Declaring them, locally allows you to use
'=== them without the CALL statement, as if they were simply another BASIC
'=== command.  Instead of placing all of these declarations in each program
'=== you want to use them in, you could use the file included with the package
'=== called QBSCR.INC by placing the following statement in your program:
'===
'===                      REM $Include: QBSCR.INC
'===
'=== This will cause the compiler to load the file QBSCR.INC at this point,
'=== which contains these declarations.  See documentation for further detail.

DECLARE FUNCTION ColorChk ()
DECLARE FUNCTION GetString$ (LeftCol!, Row%, StrLen%, FG%, BG%)
DECLARE FUNCTION MakeMenu% (Choice$(), NumOfChoices%, Justify$, LeftColumn!, RightColumn!, Row%, FG%, BG%, HFG%, HBG%)
DECLARE SUB Center (ST$, Row%)
DECLARE SUB MakeWindow (TopRow!, LeftCol!, BotRow!, RightCol!, ForeColor%, BackColor%, WindowType%, FrameType%, ShadowColor%, ExplodeType%, Label$)
DECLARE SUB Banner (ST$, Row%)
DECLARE SUB OffCenter (ST$, Row%, LeftCol!, RightCol!)


'=== Declare a few constants and dimension an array for later use ===

CONST False = 0, True = NOT False

DIM Choices$(6)


'=== SAMPLE ONE: Function "ColorChk" ===
'===
'=== Purpose: Determines whether or not a machine has color capability
'===
'=== Usage: as a boolean variable, returns TRUE (non-zero) if the machine
'===        has color capability, or FALSE (zero) if it does not.

IF ColorChk THEN
    Kolor = True
ELSE
    Kolor = False
END IF


'=== SAMPLE TWO: Sub-program "Center" ===
'===
'=== Purpose: Centers a single-line string of text on a specified screen row
'===
'=== Usage:
'===
'=== Center ST$, Row%
'===
'=== Where: ST$ is the string to center, and
'===        Row% is the Row number to display it on.  MUST be integer.

CLS
IF Kolor THEN
    COLOR 13, 0
ELSE
    COLOR 7, 0
END IF


'=== We'll just use Center to display a nice header for the rest of the samples

S$ = "=== SAMPLE PROGRAM ==="
Center S$, 1

S$ = "Demonstrating Screen Utilities for the QuickBASIC 4.0 programmer"
Center S$, 2

IF Kolor THEN
    COLOR 12, 0
ELSE
    COLOR 7, 0
END IF

S$ = "by Tony Martin"
Center S$, 3


'=== SAMPLE THREE: Sub-program "MakeWindow" ===
'===
'=== Usage:
'===
'=== MakeWindow (TopRow, LCol, BotRow, RCol, Fore%, Back%, WinType%, Frame%,
'===                  ShadowColr%, Explode%, Label$)
'===
'=== Where: TopRow      = First row window will appear on
'===        LCol        = Left-most column of window
'===        BotRow      = Last row of window
'===        RCol        = Right-most column of window
'===        Fore%       = Foreground color of window - must be INTEGER
'===        Back%       = Background color of window - must be INTEGER
'===        WinType%    = Type of window (0-9) - must be INTEGER
'===        Frame%      = Type of frame for window (0-5) - must be INTEGER
'===        ShadowColr% = Color of shadow around window (0-15) or negative
'===                      value if no shadow is desired - must be INTEGER
'===        Explode%    = Value of 1 if window is to "explode" onto screen,
'===                      0 if standard appearance - must be INTEGER
'===        Label$      = String entered for a header on top line of window.
'===                      Enter a nul string ("") if no is header desired.

'=== Make a sample window ===

LCol = 5: RCol = 75: TopRow = 5: BotRow = 21
IF Kolor THEN
    Fore% = 0: Back% = 3
ELSE
    Fore% = 0: Back% = 7
END IF
WinType% = 0: Frame% = 1: ShadowColr% = -1: Explode% = 1
Label$ = " This is the LABEL$ "

MakeWindow TopRow, LCol, BotRow, RCol, Fore%, Back%, WinType%, Frame%, ShadowColr%, Explode%, Label$

S$ = "SAMPLE WINDOW": Center S$, 8
S$ = "You saw how the window 'exploded' onto the screen?": Center S$, 11
S$ = "These lines were centered with the 'Center' sub-program.": Center S$, 13
S$ = "Hit a key to see an example of the scrolling banner...": Center S$, 14
S$ = "Window Type: 0  Frame Type: 1": Center S$, 17

Pause$ = INPUT$(1)
 

'=== EXAMPLE FOUR: Sub-program "Banner" ===
'===
'=== Purpose: To create a scrolling banner of text on a screen line
'===          The routine actually only places the first character in the
'===          string at the end, and then shifts all characters forward
'===          one space.  The scrolling effect is achieved through
'===          successive calls to Banner.
'===
'=== Usage: Banner (ST$, Row%)
'===
'=== Where: ST$   = the string to scroll as a banner
'===        Row%  = The row of the screen to place the banner on.  Must
'===                be INTEGER.

IF Kolor THEN
    COLOR 14, 0
ELSE
    COLOR 0, 7
END IF

S$ = " Hit any key to continue ": Center S$, 3
S$ = " Demonstrating Screen Utilities for the QuickBASIC 4.0 programmer "
Row% = 2
IF Kolor THEN
    COLOR 13, 0
ELSE
    COLOR 7, 0
END IF
Pause$ = ""
WHILE Pause$ = ""
    LET Pause$ = INKEY$
    Banner S$, Row%
WEND


'=== Make another window in preparation for the next sample ===

LCol = 20: RCol = 70: TopRow = 7: BotRow = 15
IF Kolor THEN
    Fore% = 15: Back% = 1
ELSE
    Fore% = 7: Back% = 0
END IF
WinType% = 3: Frame% = 4: ShadowColr% = 0: Explode% = 1
Label$ = " Sample Window 2 "

MakeWindow TopRow, LCol, BotRow, RCol, Fore%, Back%, WinType%, Frame%, ShadowColr%, Explode%, Label$


'=== SAMPLE FIVE: Sub-program "OffCenter" ===
'===
'=== Purpose: To center a string of text between two off-center coordinates
'===
'=== Usage:
'===
'=== OffCenter (ST$, Row%, LCol, RCol)
'===
'=== Where: ST$  = the string to center
'===        Row% = the row to display it on - must be INTEGER
'===        LCol = the left-most column to center between
'===        RCol = the right-most column to center between

Row% = 9
S$ = "Nice shadow, huh?": OffCenter S$, Row%, LCol, RCol
S$ = "These lines were centered with the": OffCenter S$, Row% + 1, LCol, RCol
S$ = "OffCenter sub-program.": OffCenter S$, Row% + 2, LCol, RCol
S$ = "- Hit a key to see a sample menu -": OffCenter S$, Row% + 3, LCol, RCol
S$ = "Window Type: 3   Frame Type: 4": OffCenter S$, Row% + 5, LCol, RCol

Pause$ = INPUT$(1)


'=== SAMPLE SIX: Function "MakeMenu" ===
'===
'=== Purpose: To create a menu of choices with a scrolling selection bar.
'===          Returns a result that equals the number of the selection made.
'===
'=== Usage:
'===
'=== As a function that will contain the resulting menu selection:
'===     Selection = MakeMenu%(Choices$(), NumberOfChoices, JustifyType$,
'===                          LeftCol, RightCol, Row%, FG%, BG%, HFG%, HBG%)
'===
'=== Where: Choices$()      = the string array that contains the text of your
'===                          menu choices.  Should be 25 or less.
'===        NumberOfChoices%= The actual number of choices in your menu.  Must
'===                          be INTEGER.
'===        JustifyType$    = Indicates the way you want your menu choices
'===                          justified within the boundaries you provide.
'===                          Valid values: C : Centered
'===                                        R : Right
'===                                        L : Left
'===                          Note that if (C)enter is selected, MakeMenu uses
'===                          the Center routine from the library.
'===        LeftCol         = The leftmost column to consider in placing your
'===                          menu choices.
'===        RightCol        = The rightmost column to consider in placing your
'===                          menu choices.
'===        Row%            = The row of the screen to begin placing your menu
'===                          choices. Must be INTEGER.
'===        FG%             = The Foreground color of normal menu choices.
'===        BG%             = The Background color of normal menu choices.
'===        HFG%            = The Foreground color of the highlighted choice.
'===        HBG%            = The Background color of the highlighted choice.
'===
'===        All color variables must be INTEGER.

IF Kolor THEN
    FG% = 15: BG% = 2: HFG% = 14: HBG% = 0: COLOR 15, 2: ShadowColr% = 0
ELSE
    FG% = 7: BG% = 0: HFG% = 0: HBG% = 7: COLOR 7, 0: ShadowColr% = -1
END IF


'=== Make a window with good ol' MakeWindow for the menu ===

TopRow = 8: BotRow = 19: LCol = 8: RCol = 36
WinType% = 3: Frame% = 4: Explode% = 0
Label$ = " Sample Menu "

MakeWindow TopRow, LCol, BotRow, RCol, FG%, BG%, WinType%, Frame%, ShadowColr%, Explode%, Label$

IF Kolor THEN
    COLOR FG%, BG%
ELSE
    COLOR 7, 0
END IF

LOCATE 18, 12: PRINT "Use "; CHR$(24); " and "; CHR$(25); " to select"

'=== Assign menu choices to the array that holds them ===

Choices$(1) = "Menu Choice 1"
Choices$(2) = "Menu Choice Two"
Choices$(3) = "Menu Selection 3"
Choices$(4) = "Menu Selection Four"
Choices$(5) = "Choice 5"
Choices$(6) = "Quit"

NumberOfChoices% = 6: JustifyType$ = "C": LeftCol = 13: RightCol = 33: Row% = 10


'=== Store the result of MakeMenu (the user's selection) in Result% ===

Result% = MakeMenu%(Choices$(), NumberOfChoices%, JustifyType$, LeftCol, RightCol, Row%, FG%, BG%, HFG%, HBG%)

IF Kolor THEN
    COLOR FG%, BG%
ELSE
    COLOR 7, 0
END IF


'=== Display the number of the selected choice ===

LOCATE 18, 10: PRINT "Choice:"; Result%; "   Hit a key..."

Pause$ = INPUT$(1)


'=== SAMPLE SEVEN: Function GetString$ ===
'===
'=== Purpose: Returns a string input by the user.  Allows the exclusion
'===          of certain characters by modifiying the source code.  But its
'===          real usefulness allows you to limit the length of the input
'===          string while the user is entering it.
'===
'=== Usage:
'===
'=== Variable$ = GetString$ (LCol!, Row%, StrLen%, FG%, BG%)
'===
'=== Where: Variable$ = any variable you want to store the returned string in
'===        LCol%     = The LEFT-MOST column to start display on.  Must be
'===                    INTEGER.
'===        Row%      = The row of the screen to display input on.  Must be
'===                    INTEGER.
'===        StrLen%   = The maximum length of the string you want.  Must be
'===                    INTEGER.
'===        FG%       = Foreground color to display text in.  Must be INTEGER.
'===        BG%       = Background color to display text in.  Must be INTEGER.

'=== First make a window to demonstrate in

LCol = 12: RCol = 70: TopRow = 6: BotRow = 18
IF Kolor THEN
    Fore% = 0: Back% = 2: ShadowColr% = 0
ELSE
    Fore% = 7: Back% = 0: ShadowColr% = -1
END IF
WinType% = 3: Frame% = 4: Explode% = 1
Label$ = " Using the GetString$ Function "

MakeWindow TopRow, LCol, BotRow, RCol, Fore%, Back%, WinType%, Frame%, ShadowColr%, Explode%, Label$

'=== Add some text

LOCATE TopRow + 2, LCol + 3: PRINT "To demonstrate the use of the 'GetString$' function,"
LOCATE TopRow + 3, LCol + 3: PRINT "enter any text you like in the line below.  To show"
LOCATE TopRow + 4, LCol + 3: PRINT "that the text was actually returned by the function,"
LOCATE TopRow + 5, LCol + 3: PRINT "we'll redisplay it when you're done in all caps.  Hit"
LOCATE TopRow + 6, LCol + 3: PRINT "ENTER when finished, or ESCape to abort."

'=== Print the highlighted bar to type in

StrLen% = RCol - LCol - 5
IF Kolor THEN
    FG% = 15: BG% = 0
ELSE
    FG% = 0: BG% = 7
END IF
COLOR FG%, BG%
LOCATE TopRow + 8, LCol + 3
PRINT SPACE$(StrLen%)
SampleTxt$ = GetString$(LCol + 2, TopRow + 8, StrLen%, FG%, BG%)

'=== Redisplay the text in all caps in the tiny bottom window

IF SampleTxt$ = CHR$(27) THEN SampleTxt$ = "You hit ESCape!  Entry aborted"
COLOR Fore%, Back%
OffCenter " Your Entry in CAPS    Any key continues ", TopRow + 10, LCol, RCol
OffCenter UCASE$(SampleTxt$), BotRow - 1, LCol, RCol
Pause$ = INPUT$(1)


'=== Make one last "GOODBYE" window ===

LCol = 1: RCol = 80: TopRow = 5: BotRow = 21
IF Kolor THEN
    Fore% = 15: Back% = 4
ELSE
    Fore% = 7: Back% = 0
END IF
WinType% = 0: Frame% = 1: ShadowColr% = -1: Explode% = 1
Label$ = " The Last Window "

MakeWindow TopRow, LCol, BotRow, RCol, Fore%, Back%, WinType%, Frame%, ShadowColr%, Explode%, Label$

IF Kolor THEN
    COLOR 14, 4
ELSE
    COLOR 7, 0
END IF


'=== Credits ===
                
S$ = "For more information about this and additional programs of": Center S$, 7
S$ = "interest, please contact": Center S$, 8
S$ = "The BAD SOFTWARE Company": Center S$, 10
S$ = "ATTN: Tony Martin": Center S$, 11
S$ = "7623 Matera St. #104": Center S$, 12
S$ = "Falls Church, VA 22043": Center S$, 13
S$ = "Or call our bulletin board, the Story Board, 24 hours/day, at": Center S$, 15
S$ = "703/847-0374": Center S$, 17

IF Kolor THEN COLOR 11, 4

S$ = "(Window Type: 0  Frame Type: 3)": Center S$, 19

LOCATE 21, 1

END




